@@ -117,6 +117,7 @@ class TestDateParser(BaseTestCase):
         param('21. Dezember 2013', datetime(2013, 12, 21)),
         param('19. Februar 2012', datetime(2012, 2, 19)),
         param('26. Juli 2014', datetime(2014, 7, 26)),
+        param('1. Sept 2000', datetime(2000, 9, 1)),
         param('18.10.14 um 22:56 Uhr', datetime(2014, 10, 18, 22, 56)),
         param('12-Mär-2014', datetime(2014, 3, 12)),
         param('Mit 13:14', datetime(2012, 11, 7, 13, 14)),
@@ -863,6 +864,32 @@ class TestDateParser(BaseTestCase):
         self.then_period_is('day')
         self.then_date_obj_exactly_is(expected)
 
+    @parameterized.expand([
+        param('4pm EDT', datetime(2021, 10, 19, 20, 0)),
+    ])
+    def test_date_skip_ahead(self, date_string, expected):
+        self.given_parser(settings={'PREFER_DATES_FROM': 'future',
+                                    'TO_TIMEZONE': 'etc/utc',
+                                    'RETURN_AS_TIMEZONE_AWARE': False,
+                                    'RELATIVE_BASE': datetime(2021, 10, 19, 18, 0),
+                                    })
+        self.when_date_is_parsed(date_string)
+        self.then_date_was_parsed_by_date_parser()
+        self.then_date_obj_exactly_is(expected)
+
+    @parameterized.expand([
+        param('11pm AEDT', datetime(2021, 10, 19, 12, 0)),
+    ])
+    def test_date_step_back(self, date_string, expected):
+        self.given_parser(settings={'PREFER_DATES_FROM': 'past',
+                                    'TO_TIMEZONE': 'etc/utc',
+                                    'RETURN_AS_TIMEZONE_AWARE': False,
+                                    'RELATIVE_BASE': datetime(2021, 10, 19, 18, 0),
+                                    })
+        self.when_date_is_parsed(date_string)
+        self.then_date_was_parsed_by_date_parser()
+        self.then_date_obj_exactly_is(expected)
+
     def given_local_tz_offset(self, offset):
         self.add_patch(
             patch.object(dateparser.timezone_parser,
