@@ -8,6 +8,8 @@ from dateparser_data.settings import default_parsers
 import datetime
 import pytz
 
+today = datetime.datetime.today()
+
 
 class TestTranslateSearch(BaseTestCase):
     def setUp(self):
@@ -189,6 +191,9 @@ class TestTranslateSearch(BaseTestCase):
         param('ja', "2016年3月21日(月) 14時48分"),
         param('ja', "2016年3月20日(日) 21時40分"),
         param('ja', "2016年3月20日 (日) 21時40分"),
+        param('ja', "正午"),
+        param('ja', "明後日"),
+        param('ja', "明後日の正午"),
 
         # Hebrew
         param('he', "20 לאפריל 2012"),
@@ -302,7 +307,9 @@ class TestTranslateSearch(BaseTestCase):
               [('25th march 2015', datetime.datetime(2015, 3, 25)),
                ('today', datetime.datetime(2000, 1, 1))],
               settings={'RELATIVE_BASE': datetime.datetime(2000, 1, 1)}),
-
+        param('en', 'The employee has not submitted their documents till date',
+              [('till date', datetime.datetime(2000, 1, 1))],
+              settings={'RELATIVE_BASE': datetime.datetime(2000, 1, 1)}),
         # Filipino / Tagalog
         param('tl', 'Maraming namatay sa mga Hapon hanggang sila\'y sumuko noong Agosto 15, 1945.',
               [('noong Agosto 15, 1945', datetime.datetime(1945, 8, 15, 0, 0))],
@@ -455,10 +462,8 @@ class TestTranslateSearch(BaseTestCase):
                ('February 1st', datetime.datetime(2017, 2, 1, 0, 0))]),
         param('en', '2014 was good! October was excellent!'
                     ' Friday, 21 was especially good!',
-              [('2014', datetime.datetime(
-                  2014, datetime.datetime.utcnow().month, datetime.datetime.utcnow().day, 0, 0)
-                ),
-               ('October', datetime.datetime(2014, 10, datetime.datetime.utcnow().day, 0, 0)),
+              [('2014', datetime.datetime(2014, today.month, today.day, 0, 0)),
+               ('October', datetime.datetime(2014, 10, today.day, 0, 0)),
                ('Friday, 21', datetime.datetime(2014, 10, 21, 0, 0))]),
         param('en', """May 2020
                     July 2020
@@ -524,9 +529,7 @@ class TestTranslateSearch(BaseTestCase):
                ('July 13th', datetime.datetime(2014, 7, 13, 0, 0)),
                ('July 14th', datetime.datetime(2014, 7, 14, 0, 0))]),
         param('en', '2014. July 13th July 14th',
-              [('2014', datetime.datetime(
-                  2014, datetime.datetime.utcnow().month, datetime.datetime.utcnow().day, 0, 0)
-                ),
+              [('2014', datetime.datetime(2014, today.month, today.day, 0, 0)),
                ('July 13th', datetime.datetime(2014, 7, 13, 0, 0)),
                ('July 14th', datetime.datetime(2014, 7, 14, 0, 0))]),
         param('en', 'July 13th 2014 July 14th 2014',
@@ -539,9 +542,7 @@ class TestTranslateSearch(BaseTestCase):
               [('July 13th, 2014', datetime.datetime(2014, 7, 13, 0, 0)),
                ('July 14th, 2014', datetime.datetime(2014, 7, 14, 0, 0))]),
         param('en', '2014. July 12th, July 13th, July 14th',
-              [('2014', datetime.datetime(
-                  2014, datetime.datetime.utcnow().month, datetime.datetime.utcnow().day, 0, 0)
-                ),
+              [('2014', datetime.datetime(2014, today.month, today.day, 0, 0)),
                ('July 12th', datetime.datetime(2014, 7, 12, 0, 0)),
                ('July 13th', datetime.datetime(2014, 7, 13, 0, 0)),
                ('July 14th', datetime.datetime(2014, 7, 14, 0, 0))]),
@@ -549,13 +550,8 @@ class TestTranslateSearch(BaseTestCase):
         # Swedish
         param('sv', '1938–1939 marscherade tyska soldater i Österrike samtidigt som '
                     'österrikiska soldater marscherade i Berlin.',
-              [('1938', datetime.datetime(
-                  1938, datetime.datetime.utcnow().month, datetime.datetime.utcnow().day, 0, 0)
-                ),
-               ('1939', datetime.datetime(
-                   1939, datetime.datetime.utcnow().month, datetime.datetime.utcnow().day, 0, 0)
-                )]),
-
+              [('1938', datetime.datetime(1938, today.month, today.day, 0, 0)),
+               ('1939', datetime.datetime(1939, today.month, today.day, 0, 0))]),
         # German
         param('de', 'Verteidiger der Stadt kapitulierten am 2. Mai 1945. Am 8. Mai 1945 (VE-Day) trat '
                     'bedingungslose Kapitulation der Wehrmacht in Kraft',
